pub fn parse(
s: &str
) -> Result<Vec<BorrowedFormatItem<'_>, Global>, InvalidFormatDescription>Expand description
Parse a sequence of items from the format description.
The syntax for the format description can be found in the book.
pub fn parse(
s: &str
) -> Result<Vec<BorrowedFormatItem<'_>, Global>, InvalidFormatDescription>Parse a sequence of items from the format description.
The syntax for the format description can be found in the book.